@@ -86,7 +86,7 @@ exp( loglik(PD=PD, model=toy) - loglik(PD=PD, model=uniform.model) )
 
 ## ---- eval = TRUE-------------------------------------------------------------
 set.seed(12345)
-convertPars( pars=runif(11), years=5500:7500, type='CPL' )
+CPLparsToHinges(pars=runif(11), years=5500:7500)
 
 ## ---- eval = FALSE------------------------------------------------------------
 #  library(DEoptimR)
@@ -96,13 +96,13 @@ convertPars( pars=runif(11), years=5500:7500, type='CPL' )
 #  	PDarray = PD,
 #  	type = 'CPL',
 #  	NP = 100,
-#  	Trace = TRUE)
+#  	trace = TRUE)
 
 ## ---- echo = FALSE------------------------------------------------------------
 load('vignette.3CPL.JDEoptim.best.RData')
 
 ## ---- eval = TRUE, fig.height = 4, fig.width=7, fig.align = "center", dev='svg', warning=FALSE----
-CPL <- convertPars(pars=best$par, years=5500:7500, type='CPL')
+CPL <- CPLparsToHinges(pars=best$par, years=5500:7500)
 SPD <- summedPhaseCalibrator( data=data, calcurve=shcal20, calrange=c(5500,7500) )
 plotPD(SPD)
 lines(CPL$year, CPL$pdf, lwd=2, col='firebrick')
@@ -160,6 +160,7 @@ y <- cbind(seq(1,100,length.out=N),seq(100,1,length.out=N))
 conventional <- 100 * exp(log(y[,2]/y[,1])/((x[,1]-x[,2])/25))-100
 relative <- relativeRate(x,y)
 plot(conventional, relative, type='l')
+rect(-100,-100,c(10,0,-10),c(10,0,-10), lty=2,border='grey')
 
 ## ---- eval = FALSE------------------------------------------------------------
 #  # CPL parameters must be between 0 and 1, and an odd length.
@@ -235,53 +236,172 @@ plotSimulationSummary(summary, legend.y=0.0012)
 
 ## ---- eval = FALSE------------------------------------------------------------
 #  # generate SPDs
+#  CalArray <- makeCalArray(intcal20, calrange = c(1000,4000))
 #  spd1 <- summedCalibrator(data1, CalArray, normalise='full')
 #  spd2 <- summedCalibrator(data2, CalArray, normalise='full')
 #  spd3 <- summedCalibrator(data3, CalArray, normalise='full')
 #  
 #  # calibrate phases
-#  CalArray <- makeCalArray(intcal20, calrange = c(5500,7500), inc = 5)
 #  PD1 <- phaseCalibrator(data1, CalArray, remove.external = TRUE)
 #  PD2 <- phaseCalibrator(data2, CalArray, remove.external = TRUE)
 #  PD3 <- phaseCalibrator(data3, CalArray, remove.external = TRUE)
 #  
+#  # effective sample sizes
+#  ncol(PD1)
+#  ncol(PD2)
+#  ncol(PD3)
+#  
 #  # maximum likelihood search, fitting various models to various datasets
-#  norm <- JDEoptim(lower=c(5500,1), upper=c(7500,5000), fn=objectiveFunction,
-#  		PDarray=PD1, type='norm', NP=40, trace=T)
-#  cauchy <- JDEoptim(lower=c(5500,1), upper=c(7500,5000), fn=objectiveFunction,
-#  		PDarray=PD1, type='cauchy', NP=40, trace=T)
-#  sine <- JDEoptim(lower=c(0,0,0), upper=c(1/1000,2*pi,1), fn=objectiveFunction,
-#  		PDarray=PD2, type='sine', NP=60, trace=T)
-#  logistic <- JDEoptim(lower=c(0,5000), upper=c(1,8000), fn=objectiveFunction,
-#  		PDarray=PD3, type='logistic', NP=40, trace=T)
-#  exp <- JDEoptim(lower=c(0), upper=c(1), fn=objectiveFunction,
-#  		PDarray=PD3, type='exp', NP=20, trace=T)
+#  norm <- JDEoptim(lower=c(1000,1), upper=c(4000,5000),
+#  	fn=objectiveFunction, PDarray=PD1, type='norm', NP=40, trace=T)
+#  cauchy <- JDEoptim(lower=c(1000,1), upper=c(4000,5000),
+#  	fn=objectiveFunction, PDarray=PD1, type='cauchy', NP=40, trace=T)
+#  sine <- JDEoptim(lower=c(0,0,0), upper=c(1/1000,2*pi,1),
+#  	fn=objectiveFunction, PDarray=PD2, type='sine', NP=60, trace=T)
+#  logistic <- JDEoptim(lower=c(0,0000), upper=c(1,10000),
+#  	fn=objectiveFunction, PDarray=PD3, type='logistic', NP=40, trace=T)
+#  exp <- JDEoptim(lower=c(0), upper=c(1),
+#  	fn=objectiveFunction, PDarray=PD3, type='exp', NP=20, trace=T)
+#  power <- JDEoptim(lower=c(0,-10), upper=c(10000,0),
+#  	fn=objectiveFunction, PDarray=PD3, type='power', NP=40, trace=T)
+#  
 
 ## ---- eval = FALSE------------------------------------------------------------
 #  # convert parameters to model PDs
-#  mod.norm <- convertPars(pars=norm$par, years=5500:7500, type='norm')
-#  mod.cauchy <- convertPars(pars=cauchy$par, years=5500:7500, type='cauchy')
-#  mod.sine <- convertPars(pars=sine$par, years=5500:7500, type='sine')
-#  mod.uniform <- convertPars(pars=NULL, years=5500:7500, type='uniform')
-#  mod.logistic <- convertPars(pars=logistic$par, years=5500:7500, type='logistic')
-#  mod.exp <- convertPars(pars=exp$par, years=5500:7500, type='exp')
+#  years <- 1000:4000
+#  mod.norm <- convertPars(pars=norm$par, years, type='norm')
+#  mod.cauchy <- convertPars(pars=cauchy$par, years, type='cauchy')
+#  mod.sine <- convertPars(pars=sine$par, years, type='sine')
+#  mod.uniform <- convertPars(pars=NULL, years, type='uniform')
+#  mod.logistic <- convertPars(pars=logistic$par, years, type='logistic')
+#  mod.exp <- convertPars(pars=exp$par, years, type='exp')
+#  mod.power <- convertPars(pars=power$par, years, type='power')
 #  
 #  # Plot SPDs and various fitted models:
 #  par(mfrow=c(3,1), mar=c(4,4,1,1))
-#  cols <- c('steelblue','firebrick')
+#  cols <- c('steelblue','firebrick','orange')
 #  
 #  plotPD(spd1)
-#  lines(mod.norm, col=cols[1], lwd=2)
-#  lines(mod.cauchy, col=cols[2], lwd=2)
-#  legend(x=7500, y=max(spd1), lwd=2, col=cols, bty='n', legend=c('Gaussian','Cauchy'))
+#  lines(mod.norm, col=cols[1], lwd=5)
+#  lines(mod.cauchy, col=cols[2], lwd=5)
+#  legend(x=4000, y=max(spd1)*1.2, lwd=5, col=cols, bty='n', legend=c('Gaussian','Cauchy'))
 #  
 #  plotPD(spd2)
-#  lines(mod.sine, col=cols[1], lwd=2)
-#  lines(mod.uniform, col=cols[2], lwd=2)
-#  legend(x=7500, y=max(spd2),  lwd=2, col=cols, bty='n', legend=c('Sinewave','Uniform'))
+#  lines(mod.sine, col=cols[1], lwd=5)
+#  lines(mod.uniform, col=cols[2], lwd=5)
+#  legend(x=4000, y=max(spd2)*1.2,  lwd=5, col=cols, bty='n', legend=c('Sinewave','Uniform'))
 #  
 #  plotPD(spd3)
-#  lines(mod.logistic, col=cols[1], lwd=2)
-#  lines(mod.exp, col=cols[2], lwd=2)
-#  legend(x=7500, y=max(spd3), lwd=2, col=cols, bty='n', legend=c('Logistic','Exponential'))
+#  lines(mod.logistic, col=cols[1], lwd=5)
+#  lines(mod.exp, col=cols[2], lwd=5)
+#  lines(mod.power, col=cols[3], lwd=5)
+#  legend(x=4000, y=max(spd3)*1.2, lwd=5, col=cols, bty='n', legend=c('Logistic','Exponential','Power Law'))
+
+## ---- eval = FALSE------------------------------------------------------------
+#  # generate an PD array for each dataset
+#  years <- seq(1000,40000,by=50)
+#  CalArray <- makeCalArray(intcal20, calrange = c(1000,40000),inc=50)
+#  PD1 <- phaseCalibrator(bryson1848, CalArray, remove.external = TRUE)
+#  PD2 <- phaseCalibrator(bluhm2421, CalArray, remove.external = TRUE)
+#  
+#  # MCMC search
+#  chain.bryson <- mcmc(PDarray=PD1,
+#  		startPars=c(10000,-1.5),
+#  		type='power', N=50000,
+#  		burn=2000,
+#  		thin=5,
+#  		jumps =c(250,0.075))
+#  		
+#  chain.bluhm <- mcmc(PDarray=PD2,
+#  	startPars=c(10000,-1.5),
+#  	type='power', N=50000,
+#  	burn=2000,
+#  	thin=5,
+#  	jumps =c(250,0.075))
+#  
+#  # convert parameters to taphonomy curves
+#  curve.bryson <- convertPars(chain.bryson$res, type='power', years=years)
+#  curve.bluhm <- convertPars(chain.bluhm$res, type='power', years=years)
+#  
+#  # plot
+#  plot(NULL, xlim=c(0,12000),ylim=c(-2.5,-1), xlab='parameter b', ylab='parameter c')
+#  points(chain.bryson$res, col=cols[1])
+#  points(chain.bluhm$res, col=cols[2])
+#  
+#  plot(NULL, xlim=c(0,40000),ylim=c(0,0.00025), xlab='yrs BP', ylab='PD')
+#  N <- nrow(chain.bryson$res)
+#  for(n in sample(1:N,size=1000)){
+#  	lines(years,curve.bryson[n,], col=cols[1])
+#  	lines(years,curve.bluhm[n,], col=cols[2])
+#  	}
+
+## ---- eval = FALSE------------------------------------------------------------
+#  best <- JDEoptim(lower=c(0,0,0,0,0),
+#  	upper=c(1,1,1,1,1),
+#  	fn=objectiveFunction,
+#  	PDarray=PD,
+#  	type='CPL',
+#  	taphonomy=F,
+#  	trace=T,
+#  	NP=100)
+#  	
+#  best.taph <- JDEoptim(lower=c(0,0,0,0,0,0,-3),
+#  	upper=c(1,1,1,1,1,20000,0),
+#  	fn=objectiveFunction,
+#  	PDarray=PD,
+#  	type='CPL',
+#  	taphonomy=T,
+#  	trace=T,
+#  	NP=140)
+
+## ---- echo = FALSE------------------------------------------------------------
+load('vignette.3CPL.JDEoptim.best.RData')
+load('vignette.3CPL.JDEoptim.best.taph.RData')
+
+## ---- eval = TRUE, fig.height = 4, fig.width=7, fig.align = "center", dev='svg', warning=FALSE----
+CPL <- convertPars(pars=best$par, years=5500:7500, type='CPL', taphonomy=F)
+CPL.taph <- convertPars(pars=best.taph$par, years=5500:7500, type='CPL', taphonomy=T)
+
+SPD <- summedPhaseCalibrator( data=data, calcurve=shcal20, calrange=c(5500,7500) )
+plotPD(SPD)
+lines(CPL$year, CPL$pdf, lwd=2, col=cols[1])
+lines(CPL.taph$year, CPL.taph$pdf, lwd=2, col=cols[2])
+legend(x=6300,y=0.001,legend=c('3-CPL','3-CPL with taphonomy'),bty='n',col=cols[1:2],lwd=2,cex=0.7)
+
+## ---- eval = TRUE, fig.height = 4, fig.width=7, fig.align = "center", dev='svg', warning=FALSE----
+pop <- convertPars(pars=best.taph$par[1:5], years=5500:7500, type='CPL')
+taph <- convertPars(pars=best.taph$par[6:7], years=5500:7500, type='power')
+plotPD(pop)
+title('Population dynamics')
+plotPD(taph)
+title('Taphonomic loss')
+
+## ---- eval = TRUE-------------------------------------------------------------
+CPLparsToHinges(pars=best.taph$par[1:5], years=5500:7500)
+
+## ---- eval = FALSE------------------------------------------------------------
+#  chain.taph <- mcmc(PDarray = PD,
+#  	startPars = c(0.5,0.5,0.5,0.5,0.5,10000,-1.5),
+#  	type='CPL', taphonomy=T,
+#  	N = 30000,
+#  	burn = 2000,
+#  	thin = 5,
+#  	jumps = 0.025)
+
+## ---- eval = FALSE------------------------------------------------------------
+#  # convert parameters into model PDFs
+#  pop <- convertPars(pars=chain.taph$res[,1:5], years=5500:7500, type='CPL')
+#  taph <- convertPars(pars=chain.taph$res[,6:7], years=seq(1000,30000,by=50), type='power')
+#  
+#  # plot population dynamics PDF
+#  plot(NULL, xlim=c(7500,5500),ylim=c(0,0.0013), xlab='calBP', ylab='PD', las=1)
+#  for(n in 1:nrow(pop))lines(5500:7500, pop[n,],col=alpha(1,0.05))
+#  
+#  # plot taphonomy PDF
+#  plot(NULL, xlim=c(30000,0),ylim=c(0,0.00025), xlab='calBP', ylab='PD',las=1,)
+#  for(n in 1:nrow(taph))lines(seq(1000,30000,by=50), taph[n,],col=alpha(1,0.02))
+#  
+#  # plot taphonomic parameters
+#  plot(NULL, xlim=c(0,20000),ylim=c(-3,0), xlab='parameter b', ylab='parameter c',las=1)
+#  for(n in 1:nrow(chain.taph$res))points(chain.taph$res[n,6], chain.taph$res[n,7],col=alpha(1,0.2),pch=20)
 
